tlslite.integration.smtp_tls.SMTP_TLS

Package tlslite :: Package integration :: Module smtp_tls :: Class SMTP_TLS |
[hide private]
[frames] | no frames]

# Class SMTP_TLS

source code

    smtplib.SMTP --+
                   |
                  SMTP_TLS

This class extends `smtplib.SMTP` with TLS support.

Instance Methods | [hide private]
starttls(self, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None) Puts the connection to the SMTP server into TLS mode. | source code
Inherited from `smtplib.SMTP`: `__init__`, `close`, `connect`, `data`, `docmd`, `ehlo`, `ehlo_or_helo_if_needed`, `expn`, `getreply`, `has_extn`, `helo`, `help`, `login`, `mail`, `noop`, `putcmd`, `quit`, `rcpt`, `rset`, `send`, `sendmail`, `set_debuglevel`, `verify`, `vrfy` Inherited from `smtplib.SMTP` (private): `_get_socket`

Class Variables | [hide private]
Inherited from `smtplib.SMTP`: `debuglevel`, `default_port`, `does_esmtp`, `ehlo_msg`, `ehlo_resp`, `file`, `helo_resp`

Method Details | [hide private]

### starttls(self, username=None, password=None, certChain=None, privateKey=None, checker=None, settings=None) | source code
Puts the connection to the SMTP server into TLS mode. If the server supports TLS, this will encrypt the rest of the SMTP session. For client authentication, use one of these argument combinations: username, password (SRP) certChain, privateKey (certificate) For server authentication, you can either rely on the implicit mutual authentication performed by SRP or you can do certificate-based server authentication with one of these argument combinations: x509Fingerprint Certificate-based server authentication is compatible with SRP or certificate-based client authentication. The caller should be prepared to handle TLS-specific exceptions. See the client handshake functions in tlslite.TLSConnection.TLSConnection for details on which exceptions might be raised. Parameters: `username` (str) - SRP username. Requires the 'password' argument. `password` (str) - SRP password for mutual authentication. Requires the 'username' argument. `certChain` (tlslite.x509certchain.X509CertChain) - Certificate chain for client authentication. Requires the 'privateKey' argument. Excludes the SRP arguments. `privateKey` (tlslite.utils.rsakey.RSAKey) - Private key for client authentication. Requires the 'certChain' argument. Excludes the SRP arguments. `checker` (tlslite.checker.Checker) - Callable object called after handshaking to evaluate the connection and raise an Exception if necessary. `settings` (tlslite.handshakesettings.HandshakeSettings) - Various settings which can be used to control the ciphersuites, certificate types, and SSL/TLS versions offered by the client. Overrides: smtplib.SMTP.starttls